summaryrefslogtreecommitdiff
path: root/sources/prefs
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2008-08-04 20:44:54 +0000
committerPaul Buetow <paul@buetow.org>2008-08-04 20:44:54 +0000
commit8ae434c63e6382a8cb850551d947285f5fcb3c25 (patch)
tree751b0b24cd86768d57e9338cf0718485f68a095e /sources/prefs
parentbb4eb6634485d05e9e8cff6497c60ef696a28eeb (diff)
restructured stuff
Diffstat (limited to 'sources/prefs')
-rw-r--r--sources/prefs/VSDefaultPrefs.java2
-rw-r--r--sources/prefs/editors/VSProcessEditor.java6
2 files changed, 5 insertions, 3 deletions
diff --git a/sources/prefs/VSDefaultPrefs.java b/sources/prefs/VSDefaultPrefs.java
index afd79de..3865947 100644
--- a/sources/prefs/VSDefaultPrefs.java
+++ b/sources/prefs/VSDefaultPrefs.java
@@ -274,5 +274,7 @@ public class VSDefaultPrefs extends VSPrefs {
initBoolean("sim.message.prob.mean", true, "Mittelwerte der Nachrichtverlustw'k. bilden");
initBoolean("sim.messages.relevant", true, "Nur relevante Nachrichten anzeigen");
initBoolean("sim.periodic", false, "Simulation periodisch wiederholen");
+ initBoolean("sim.update.lamporttime.all", false, "Lamportzeiten betreffen alle Ereignisse");
+ initBoolean("sim.update.vectortime.all", false, "Vektorzeiten betreffen alle Ereignisse");
}
}
diff --git a/sources/prefs/editors/VSProcessEditor.java b/sources/prefs/editors/VSProcessEditor.java
index 904bfff..ae2a61f 100644
--- a/sources/prefs/editors/VSProcessEditor.java
+++ b/sources/prefs/editors/VSProcessEditor.java
@@ -33,7 +33,7 @@ import events.*;
import prefs.VSPrefs;
/**
* The class VSProcessEditor, is for editing a VSProcess object.
*
* @author Paul C. Buetow
*/
@@ -42,7 +42,7 @@ public class VSProcessEditor extends VSAbstractBetterEditor {
private static final long serialVersionUID = 1L;
/** The process. */
- private VSProcess process;
+ private VSInternalProcess process;
/** The TAKEOVE r_ button. */
public static boolean TAKEOVER_BUTTON;
@@ -53,7 +53,7 @@ public class VSProcessEditor extends VSAbstractBetterEditor {
* @param prefs the prefs
* @param process the process
*/
- public VSProcessEditor(VSPrefs prefs, VSProcess process) {
+ public VSProcessEditor(VSPrefs prefs, VSInternalProcess process) {
super(prefs, process, prefs.getString("lang.name") + " - " +
prefs.getString("lang.prefs.process"));;
this.process = process;
@@ -33,7 +33,7 @@ import events.*;
import prefs.VSPrefs;
/**
- * The class VSProcessEditor, is for editing a VSProcess object.
+ * The class VSProcessEditor, is for editing a VSInternalProcess object.
*
* @author Paul C. Buetow